@@ -25,22 +25,20 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Edit" : "Editar",
     "Delete" : "Borrar",
-    "Edit name" : "Editar nombre",
-    "Edit color" : "Editar color",
-    "Export" : "Exportar",
-    "Share link" : "Compartir link",
-    "Copy public link" : "Copiar link publico",
-    "Copied link" : "Link copiado",
-    "Copied code" : "Código copiado",
-    "Share with users or groups" : "Compartir con usuarios o grupos",
-    "No users or groups" : "No hay usuarios ni grupos.",
-    "can edit" : "puede editar",
     "New calendar" : "Nuevo calendario",
     "New calendar with task list" : "Nuevo calendario con listado de tareas",
+    "Copied link" : "Link copiado",
+    "Export" : "Exportar",
     "Name" : "Nombre",
     "Deleted" : "Eliminado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Share link" : "Compartir link",
+    "Copy public link" : "Copiar link publico",
+    "Copied code" : "Código copiado",
+    "can edit" : "puede editar",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "No users or groups" : "No hay usuarios ni grupos.",
     "Filename" : "Nombre de archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
