@@ -19,17 +19,18 @@ OC.L10N.register(
     "Copy link" : "Kopēt saiti",
     "Edit" : "Rediģēt",
     "Delete" : "Dzēst",
-    "Export" : "Eksportēt",
-    "Share link" : "Koplietot saiti",
-    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
-    "No users or groups" : "Nav lietotāji vai grupas",
-    "can edit" : "var rediģēt",
     "New calendar" : "Jauns kalendārs",
     "New calendar with task list" : "Jauns kalendārs ar uzdevumu sarakstu",
+    "Export" : "Eksportēt",
     "Name" : "Vārds",
     "Deleted" : "Dzēstie",
     "Restore" : "Atjaunot",
     "Delete permanently" : "Dzēst pavisam",
+    "Share link" : "Koplietot saiti",
+    "Copy public link" : "Kopējiet publisko saiti",
+    "can edit" : "var rediģēt",
+    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
+    "No users or groups" : "Nav lietotāji vai grupas",
     "Filename" : "Datnes nosaukums",
     "Cancel" : "Atcelt",
     "Automatic" : "Automātisks",
@@ -37,6 +38,8 @@ OC.L10N.register(
     "Actions" : "Darbības",
     "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
     "Show week numbers" : "Rādīt nedēļu numurus",
+    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
+    "Appointment name" : "Tikšanās nosaukums",
     "Location" : "Vieta",
     "Description" : "Apraksts",
     "to" : "kam",
