@@ -29,26 +29,21 @@ OC.L10N.register(
     "Delete" : "Suprimir",
     "Add new" : "Apondre novèl",
     "Untitled calendar" : "Calendièr sens nom",
-    "Edit name" : "Modificar lo nom",
-    "Saving name …" : "Enregistrament del nom …",
-    "Edit color" : "Modificar la color",
-    "Saving color …" : "Enregistrament de la color …",
-    "Copy private link" : "Copiar lo ligam privat",
-    "Export" : "Exportar",
-    "Share link" : "Partejar lo ligam",
-    "Publish calendar" : "Publicar lo calendièr",
-    "Copy public link" : "Copiar lo ligam public",
-    "Copied link" : "Ligam copiat",
-    "Copied code" : "Còdi copiat",
-    "Could not copy code" : "Se poguèt pas copiar lo còdi",
-    "can edit" : "pòt modificar",
     "New calendar" : "Calendièr novèl",
     "Name for new calendar" : "Nom del calendièr novèl",
     "Creating calendar …" : "Creacion del calendièr…",
+    "Copied link" : "Ligam copiat",
+    "Export" : "Exportar",
     "Name" : "Nom",
     "Deleted" : "Suprimit",
     "Restore" : "Restaurar",
     "Delete permanently" : "Suprimir definitivament",
+    "Share link" : "Partejar lo ligam",
+    "Copy public link" : "Copiar lo ligam public",
+    "Copied code" : "Còdi copiat",
+    "Could not copy code" : "Se poguèt pas copiar lo còdi",
+    "can edit" : "pòt modificar",
+    "Copy private link" : "Copiar lo ligam privat",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
