@@ -21,23 +21,21 @@ OC.L10N.register(
     "Copy link" : "Копирај везу",
     "Edit" : "Измени",
     "Delete" : "Обриши",
-    "Edit name" : "Измени име",
-    "Copy private link" : "Копирај приватну везу",
+    "New calendar" : "Нови календар",
     "Export" : "Извези",
-    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
     "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
     "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
-    "Share link" : "Дели везу",
-    "Delete share link" : "Обриши везу дељења",
-    "Share with users or groups" : "Дели са корисницима или групама",
-    "No users or groups" : "Нема корисника или група",
-    "can edit" : "може да мења",
-    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
-    "New calendar" : "Нови календар",
     "Name" : "Име",
     "Deleted" : "Обрисано",
     "Restore" : "Врати",
     "Delete permanently" : "Обриши заувек",
+    "Share link" : "Дели везу",
+    "Delete share link" : "Обриши везу дељења",
+    "can edit" : "може да мења",
+    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
+    "Share with users or groups" : "Дели са корисницима или групама",
+    "No users or groups" : "Нема корисника или група",
+    "Copy private link" : "Копирај приватну везу",
     "Filename" : "Име фајла",
     "Cancel" : "Одустани",
     "Automatic" : "Аутоматски",
@@ -104,6 +102,8 @@ OC.L10N.register(
     "Canceled" : "Отказано",
     "Categories" : "Категорије",
     "Add this as a new category" : "Додај ово као нову категорију",
+    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
+    "Money" : "Новац",
     "Talk" : "Разговор",
     "Movie" : "Филм",
     "Cinema" : "Биоскоп",
